#
# TV::Fetch::Test   - a simple class to simulate fetching a channel
# ~~~~~~~~~~~~~~~     (c) Andrew Flegg <andrew@bleb.org>, http://www.bleb.org/
# v0.01 (08-Jan-2003) Released under the Artistic Licence.
# 
#
# Methods to be implemented:
#         TV::Fetch::Test->new           (<channel id>, <XML data>)
#         TV::Fetch::Test->getProgrammes (<offset>)

package TV::Fetch::Test;
use Date::Calc;

# -- We're created ------------------------------------------------------
#
sub new {
    my $class    = shift;
    my $channel  = shift || die "No channel name passed to $class";
    my $data     = shift || die "No XML data passed to $class";
    my $self     = bless { channel => $channel, data => $data }, $class;

    return $self;
}


# -- Return data on programmes listings --------------------------------
#
sub getProgrammes {
    my $self   = shift;
    my $offset = @_;
    my @data   = ();

    my @lastend = (Date::Calc::Today(), 00,00,00);
    my $today   = $lastend[2];
    while ($today == $lastend[2]) {
        my %entry = ();
        $entry{start} = $lastend[3]*100 + $lastend[4];

        my $duration = int(rand(4)+1) * 30;
        @lastend     = Date::Calc::Add_Delta_DHMS(@lastend, 0, 0, $duration, 0);

        $entry{end}     = $lastend[3]*100 + $lastend[4];
        $entry{title}   = "Random programme from $entry{start} to $entry{end}";
        $entry{desc}    = "Some random description";
        $entry{infourl} = '/cgi-bin/tv/info.cgi?id=4232';
        push @data, \%entry;
    }

    return \@data;
}


1;
