#
# TV::Fetch::XML   - fetch listings from bleb.org's XML repository
# ~~~~~~~~~~~~~~     (c) Andrew Flegg <andrew@bleb.org>, http://www.bleb.org/
# v0.01 (25-Jan-2004) Released under the Artistic Licence.
# 
#
# Methods to be implemented:
#         TV::Fetch::XML->new      (<channel id>, <XML data>)
#         $obj->getProgrammes       (<offset>)
#         TV::Fetch::XML->getInfo  (<programme>)
# Additionally:
#         TV::Fetch::XML->getChannelList

package TV::Fetch::XML;

use XML::Simple;
use TV::Fetch;
use vars qw($URL $UA);

$URL  = 'http://www.bleb.org/tv/data/listings/';
$UA   = 'TV::Fetch::XML, http://www.bleb.org/tv/ - listmail@bleb.org';

# -- We're created ------------------------------------------------------
#
sub new {
    my $class    = shift;
    my $channel  = shift || die "No channel name passed to $class";
    my $data     = shift || die "No XML data passed to $class";
    my $self     = bless { channel => $channel, data => $data }, $class;

    return $self;
}


# -- Get programme info ------------------------------------------------
#
sub getInfo {
    my $class = shift;
    my $prog  = shift;
    my $url   = $prog->{infourl} or return '';

    return "<a href=\"$url\">More info...</a>";
}


# -- Return data on programmes listings --------------------------------
#
sub getProgrammes {
    my $self   = shift;
    my $offset = shift;
    my $url    = "$URL/$offset/".$self->{data}->{channel}.'.xml';

    print "+++ Fetching $url... " if $self->{data}->{debug};
    $TV::Fetch::UA->agent($UA);
    my $xml    = TV::Fetch::get($url) or return undef;
    print "done.\n" if $self->{data}->{debug};

    my $parsed = XMLin($xml);
    return $parsed->{programme};
}


# -- Get available list of channels -----------------------------------
#
sub getChannelList {
    my $class = shift;

    $TV::Fetch::UA->agent($UA);
    my $raw  = TV::Fetch::get($URL.'0/') or return undef;
    my %data = map { $_ => 1 } $raw =~ /\b(\w+).xml\b/g;
    my @list = keys(%data);

    return \@list;
}

1;
