#!/usr/bin/perl -w

BEGIN { do "/home/jaffa/lib/loadperl.pm"; }

use strict;
use TV::Core;
use TV::Fetch;

use Data::Dumper;
use Getopt::Long;

my %options = ();
GetOptions(\%options, "help",
                      "debug|d",
                      "force",
                      "shift",
                      "day|o=i",
                      "week");
die <<EOM if $options{'help'};
fetchtv [options] [<channel>...]        (c) Andrew Flegg 2002.
~~~~~~~                                 Released under the Artistic Licence.
Options:
    -h, --help                  This message
    -d, --debug                 Print information on each channel fetched
    -s, --shift                 Shift +6 to +5 etc. before starting
    -f, --force                 Refetch listings if already exist
    -o, --day=OFFSET            Fetch only the particular day
    -w, --week                  Fetch a whole weeks worth of programmes

Contact <andrew\@bleb.org> in case of problems.
EOM

$| = 1;
my @range         = ($options{'week'} ? 0..6 : (0));
@range            = ($options{'day'}) if $options{'day'};
$TV::Fetch::DEBUG = 1 if $options{'debug'};
$TV::Fetch::FORCE = 1 if $options{'force'};

# -- Shift existing data as a backup...
#
if ($options{'shift'}) {
    my $now = time;
    my $data = $TV::Core::DATA_DIR.'/listings';
    system('/bin/rm', '-rf', "$data/-1");
    warn "+++ rm $data/-1 failed: $!\n" if $!;
    for (my $day=0; $day<=6; $day++) {
        my $target = $day - 1;
        print "+++ Renaming $data/$day to $target...\n" if $TV::Fetch::DEBUG;
        rename "$data/$day", "$data/$target";
        utime $now, $now, <$data/$target/*.xml>;
    }
    mkdir "$data/6", 0755;
}


my $channels = defined($ARGV[0]) ? \@ARGV : TV::Core->getChannels();
my $num      = scalar(@$channels);
for (my $i = 0; $i < $num; $i++) {
    my $c = $channels->[$i];
    print "+++ Starting fetch for $c ($i/$num)...\n" if $options{'debug'};
    TV::Fetch->store($c, @range);
}

exit;

